import os
import json

from tap_nice_incontact.transform import convert_data_types

def get_abs_path(path):
    return os.path.join(os.path.dirname(os.path.realpath(__file__)), path)

RAW_SKILLS_SUMMARIES = [
    {
        "startDate": "2021-07-27T00:00:00",
        "endDate": "2021-07-28T00:00:00",
        "businessUnitId": "459957",
        "businessUnitName": "BUSSINESSNAME",
        "abandonCount": "0",
        "abandonRate": "0",
        "agentsAcw": "0",
        "agentsAvailable": "5",
        "agentsIdle": "5",
        "agentsLoggedIn": "24",
        "agentsUnavailable": "9",
        "agentsWorking": "6",
        "averageHandleTime": "101",
        "averageInqueueTime": "0",
        "averageSpeedToAnswer": "0",
        "averageTalkTime": "101",
        "averageWrapTime": "0",
        "campaignId": "2577193",
        "campaignName": "Concierge",
        "contactsActive": "5",
        "contactsHandled": "2089",
        "contactsOffered": "2089",
        "contactsQueued": "0",
        "contactsOutOfSLA": "0",
        "contactsWithinSLA": "0",
        "holdTime": "976",
        "isOutbound": "True",
        "longestQueueDur": "0",
        "mediaTypeId": "4",
        "mediaTypeName": "Phone Call",
        "queueCount": "0",
        "serviceLevel": "100",
        "skillName": "Concierges-OB",
        "skillId": "8408918",
        "serviceLevelGoal": "90",
        "serviceLevelThreshold": "30",
        "totalContactTime": "214308",
        "dials": "2089",
        "connects": "1918",
        "connectsAHT": "0.11",
        "rightPartyConnects": "0",
        "rightPartyConnectsAHT": "0.00"
    },
    {
        "startDate": "2021-07-27T00:00:00",
        "endDate": "2021-07-28T00:00:00",
        "businessUnitId": "459957",
        "businessUnitName": "BUSSINESSNAME",
        "abandonCount": "0",
        "abandonRate": "0",
        "agentsAcw": "2",
        "agentsAvailable": "0",
        "agentsIdle": "0",
        "agentsLoggedIn": "2",
        "agentsUnavailable": "0",
        "agentsWorking": "2",
        "averageHandleTime": "179",
        "averageInqueueTime": "1944",
        "averageSpeedToAnswer": "1944",
        "averageTalkTime": "179",
        "averageWrapTime": "0",
        "campaignId": "2577195",
        "campaignName": "Sales Operations",
        "contactsActive": "2",
        "contactsHandled": "1036",
        "contactsOffered": "1036",
        "contactsQueued": "1036",
        "contactsOutOfSLA": "2",
        "contactsWithinSLA": "1033",
        "holdTime": "0",
        "isOutbound": "False",
        "longestQueueDur": "0",
        "mediaTypeId": "1",
        "mediaTypeName": "E-Mail",
        "queueCount": "0",
        "serviceLevel": "100",
        "skillName": "Sales Operations Email",
        "skillId": "10477448",
        "serviceLevelGoal": "70",
        "serviceLevelThreshold": "28800",
        "totalContactTime": "2201446",
        "dials": "0",
        "connects": "997",
        "connectsAHT": "0.19",
        "rightPartyConnects": "0",
        "rightPartyConnectsAHT": "0.00"
    }
]

EXPECTED_SKILLS_SUMMARIES = [
    {
        "startDate": "2021-07-27T00:00:00",
        "endDate": "2021-07-28T00:00:00",
        "businessUnitId": 459957,
        "businessUnitName": "BUSSINESSNAME",
        "abandonCount": 0,
        "abandonRate": 0,
        "agentsAcw": 0,
        "agentsAvailable": 5,
        "agentsIdle": 5,
        "agentsLoggedIn": 24,
        "agentsUnavailable": 9,
        "agentsWorking": 6,
        "averageHandleTime": 101,
        "averageInqueueTime": 0,
        "averageSpeedToAnswer": 0,
        "averageTalkTime": 101,
        "averageWrapTime": 0,
        "campaignId": 2577193,
        "campaignName": "Concierge",
        "contactsActive": 5,
        "contactsHandled": 2089,
        "contactsOffered": 2089,
        "contactsQueued": 0,
        "contactsOutOfSLA": 0,
        "contactsWithinSLA": 0,
        "holdTime": 976,
        "isOutbound": True,
        "longestQueueDur": 0,
        "mediaTypeId": 4,
        "mediaTypeName": "Phone Call",
        "queueCount": 0,
        "serviceLevel": 100,
        "skillName": "Concierges-OB",
        "skillId": 8408918,
        "serviceLevelGoal": 90,
        "serviceLevelThreshold": 30,
        "totalContactTime": 214308,
        "dials": 2089,
        "connects": 1918,
        "connectsAHT": "0.11",
        "rightPartyConnects": 0,
        "rightPartyConnectsAHT": "0.00"
    },
    {
        "startDate": "2021-07-27T00:00:00",
        "endDate": "2021-07-28T00:00:00",
        "businessUnitId": 459957,
        "businessUnitName": "BUSSINESSNAME",
        "abandonCount": 0,
        "abandonRate": 0,
        "agentsAcw": 2,
        "agentsAvailable": 0,
        "agentsIdle": 0,
        "agentsLoggedIn": 2,
        "agentsUnavailable": 0,
        "agentsWorking": 2,
        "averageHandleTime": 179,
        "averageInqueueTime": 1944,
        "averageSpeedToAnswer": 1944,
        "averageTalkTime": 179,
        "averageWrapTime": 0,
        "campaignId": 2577195,
        "campaignName": "Sales Operations",
        "contactsActive": 2,
        "contactsHandled": 1036,
        "contactsOffered": 1036,
        "contactsQueued": 1036,
        "contactsOutOfSLA": 2,
        "contactsWithinSLA": 1033,
        "holdTime": 0,
        "isOutbound": False,
        "longestQueueDur": 0,
        "mediaTypeId": 1,
        "mediaTypeName": "E-Mail",
        "queueCount": 0,
        "serviceLevel": 100,
        "skillName": "Sales Operations Email",
        "skillId": 10477448,
        "serviceLevelGoal": 70,
        "serviceLevelThreshold": 28800,
        "totalContactTime": 2201446,
        "dials": 0,
        "connects": 997,
        "connectsAHT": "0.19",
        "rightPartyConnects": 0,
        "rightPartyConnectsAHT": "0.00"
    }
]

def test_convert_data_types():
    path = get_abs_path("../tap_nice_incontact/schemas/skills_summary.json")
    with open(path) as file:
        schema = json.load(file)

    for index, record in enumerate(RAW_SKILLS_SUMMARIES):

        assert convert_data_types(record, schema) == EXPECTED_SKILLS_SUMMARIES[index]
